@@ -103,11 +103,12 @@ def writeChannels(chanInfo, bak=backUpVals):
             for ch in chanInfo['channels']:
                 fus = ch.rfind('_') + 1
                 if ch[fus:] in ['GAIN', 'OFFSET']:
-                    try:
-                        trampCh = ch[:fus] + 'TRAMP'
-                        oldTramps[trampCh] = caget(trampCh)
+                    trampCh = ch[:fus] + 'TRAMP'
+                    oldTrampVal = caget(trampCh, timeout=0.2)
+                    if oldTrampVal is not None:
+                        oldTramps[trampCh] = oldTrampVal
                         rampYourself = rampYourself and False
-                    except BaseException:
+                    else:
                         rampYourself = rampYourself or True
                 else:
                     rampYourself = rampYourself or True
